"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var net_1 = require("net");
/**
 * Find next open port
 * @example
 * findPort(8000, (err, port) => console.log(`${port} is open`))
 */
var findPort = function (port, cb) {
    var server = net_1.createServer(function () { });
    var onListen = function () {
        server.close();
        cb(null, port);
    };
    // eslint-disable-next-line @typescript-eslint/no-use-before-define
    server.once('error', onError);
    server.once('listening', onListen);
    server.listen(port);
    // eslint-disable-next-line func-style
    function onError(err) {
        server.removeListener('listening', onListen);
        if (err.code && ['EADDRINUSE', 'EACCESS'].includes(err.code)) {
            return cb(err);
        }
        findPort(port + 1, cb);
    }
};
exports.default = findPort;
